@@ -19,7 +19,9 @@ namespace validation_layer
 
     class ZESHandleLifetimeValidation : public ZESValidationEntryPoints {
     public:
-                        ze_result_t zesDeviceGet ( zes_driver_handle_t hDriver, uint32_t* pCount, zes_device_handle_t* phDevices ) override;
+                        ze_result_t zesDriverGetExtensionProperties ( zes_driver_handle_t hDriver, uint32_t* pCount, zes_driver_extension_properties_t* pExtensionProperties ) override;
+        ze_result_t zesDriverGetExtensionFunctionAddress ( zes_driver_handle_t hDriver, const char* name, void** ppFunctionAddress ) override;
+        ze_result_t zesDeviceGet ( zes_driver_handle_t hDriver, uint32_t* pCount, zes_device_handle_t* phDevices ) override;
         ze_result_t zesDeviceGetProperties ( zes_device_handle_t hDevice, zes_device_properties_t* pProperties ) override;
         ze_result_t zesDeviceGetState ( zes_device_handle_t hDevice, zes_device_state_t* pState ) override;
         ze_result_t zesDeviceReset ( zes_device_handle_t hDevice, ze_bool_t force ) override;
@@ -55,7 +57,6 @@ namespace validation_layer
         ze_result_t zesDeviceEnumEngineGroups ( zes_device_handle_t hDevice, uint32_t* pCount, zes_engine_handle_t* phEngine ) override;
         ze_result_t zesEngineGetProperties ( zes_engine_handle_t hEngine, zes_engine_properties_t* pProperties ) override;
         ze_result_t zesEngineGetActivity ( zes_engine_handle_t hEngine, zes_engine_stats_t* pStats ) override;
-        ze_result_t zesEngineGetActivityExt ( zes_engine_handle_t hEngine, uint32_t* pCount, zes_engine_stats_t* pStats ) override;
         ze_result_t zesDeviceEventRegister ( zes_device_handle_t hDevice, zes_event_type_flags_t events ) override;
         ze_result_t zesDriverEventListen ( ze_driver_handle_t hDriver, uint32_t timeout, uint32_t count, zes_device_handle_t* phDevices, uint32_t* pNumDeviceEvents, zes_event_type_flags_t* pEvents ) override;
         ze_result_t zesDriverEventListenEx ( ze_driver_handle_t hDriver, uint64_t timeout, uint32_t count, zes_device_handle_t* phDevices, uint32_t* pNumDeviceEvents, zes_event_type_flags_t* pEvents ) override;
@@ -78,6 +79,8 @@ namespace validation_layer
         ze_result_t zesDeviceEnumFirmwares ( zes_device_handle_t hDevice, uint32_t* pCount, zes_firmware_handle_t* phFirmware ) override;
         ze_result_t zesFirmwareGetProperties ( zes_firmware_handle_t hFirmware, zes_firmware_properties_t* pProperties ) override;
         ze_result_t zesFirmwareFlash ( zes_firmware_handle_t hFirmware, void* pImage, uint32_t size ) override;
+        ze_result_t zesFirmwareGetFlashProgress ( zes_firmware_handle_t hFirmware, uint32_t* pCompletionPercent ) override;
+        ze_result_t zesFirmwareGetConsoleLogs ( zes_firmware_handle_t hFirmware, size_t* pSize, char* pFirmwareLog ) override;
         ze_result_t zesDeviceEnumFrequencyDomains ( zes_device_handle_t hDevice, uint32_t* pCount, zes_freq_handle_t* phFrequency ) override;
         ze_result_t zesFrequencyGetProperties ( zes_freq_handle_t hFrequency, zes_freq_properties_t* pProperties ) override;
         ze_result_t zesFrequencyGetAvailableClocks ( zes_freq_handle_t hFrequency, uint32_t* pCount, double* phFrequency ) override;
@@ -145,6 +148,19 @@ namespace validation_layer
         ze_result_t zesTemperatureGetState ( zes_temp_handle_t hTemperature, double* pTemperature ) override;
         ze_result_t zesPowerGetLimitsExt ( zes_pwr_handle_t hPower, uint32_t* pCount, zes_power_limit_ext_desc_t* pSustained ) override;
         ze_result_t zesPowerSetLimitsExt ( zes_pwr_handle_t hPower, uint32_t* pCount, zes_power_limit_ext_desc_t* pSustained ) override;
+        ze_result_t zesEngineGetActivityExt ( zes_engine_handle_t hEngine, uint32_t* pCount, zes_engine_stats_t* pStats ) override;
+        ze_result_t zesRasGetStateExp ( zes_ras_handle_t hRas, uint32_t* pCount, zes_ras_state_exp_t* pState ) override;
+        ze_result_t zesRasClearStateExp ( zes_ras_handle_t hRas, zes_ras_error_category_exp_t category ) override;
+        ze_result_t zesFirmwareGetSecurityVersionExp ( zes_firmware_handle_t hFirmware, char* pVersion ) override;
+        ze_result_t zesFirmwareSetSecurityVersionExp ( zes_firmware_handle_t hFirmware ) override;
+        ze_result_t zesDeviceGetSubDevicePropertiesExp ( zes_device_handle_t hDevice, uint32_t* pCount, zes_subdevice_exp_properties_t* pSubdeviceProps ) override;
+        ze_result_t zesDriverGetDeviceByUuidExp ( zes_driver_handle_t hDriver, zes_uuid_t uuid, zes_device_handle_t* phDevice, ze_bool_t* onSubdevice, uint32_t* subdeviceId ) override;
+        ze_result_t zesDeviceEnumActiveVFExp ( zes_device_handle_t hDevice, uint32_t* pCount, zes_vf_handle_t* phVFhandle ) override;
+        ze_result_t zesVFManagementGetVFPropertiesExp ( zes_vf_handle_t hVFhandle, zes_vf_exp_properties_t* pProperties ) override;
+        ze_result_t zesVFManagementGetVFMemoryUtilizationExp ( zes_vf_handle_t hVFhandle, uint32_t* pCount, zes_vf_util_mem_exp_t* pMemUtil ) override;
+        ze_result_t zesVFManagementGetVFEngineUtilizationExp ( zes_vf_handle_t hVFhandle, uint32_t* pCount, zes_vf_util_engine_exp_t* pEngineUtil ) override;
+        ze_result_t zesVFManagementSetVFTelemetryModeExp ( zes_vf_handle_t hVFhandle, zes_vf_info_util_exp_flags_t flags, ze_bool_t enable ) override;
+        ze_result_t zesVFManagementSetVFTelemetrySamplingIntervalExp ( zes_vf_handle_t hVFhandle, zes_vf_info_util_exp_flags_t flag, uint64_t samplingInterval ) override;
     };
 
 }
