@@ -1,6 +1,6 @@
 /*
  *
- * Copyright (C) 2019-2022 Intel Corporation
+ * Copyright (C) 2019-2024 Intel Corporation
  *
  * SPDX-License-Identifier: MIT
  *
@@ -21,95 +21,109 @@ namespace ze_lib
     {
         ze_result_t result = ZE_RESULT_SUCCESS;
 
+        if( ZE_RESULT_SUCCESS == result )
+        {
+            auto getTable = reinterpret_cast<zet_pfnGetMetricProgrammableExpProcAddrTable_t>(
+                GET_FUNCTION_PTR(loader, "zetGetMetricProgrammableExpProcAddrTable") );
+            result = getTable( ZE_API_VERSION_CURRENT, &initialzetDdiTable.MetricProgrammableExp );
+        }
+
         if( ZE_RESULT_SUCCESS == result )
         {
             auto getTable = reinterpret_cast<zet_pfnGetDeviceProcAddrTable_t>(
                 GET_FUNCTION_PTR(loader, "zetGetDeviceProcAddrTable") );
-            result = getTable( ZE_API_VERSION_CURRENT, &zetDdiTable.Device );
+            result = getTable( ZE_API_VERSION_CURRENT, &initialzetDdiTable.Device );
         }
 
         if( ZE_RESULT_SUCCESS == result )
         {
             auto getTable = reinterpret_cast<zet_pfnGetContextProcAddrTable_t>(
                 GET_FUNCTION_PTR(loader, "zetGetContextProcAddrTable") );
-            result = getTable( ZE_API_VERSION_CURRENT, &zetDdiTable.Context );
+            result = getTable( ZE_API_VERSION_CURRENT, &initialzetDdiTable.Context );
         }
 
         if( ZE_RESULT_SUCCESS == result )
         {
             auto getTable = reinterpret_cast<zet_pfnGetCommandListProcAddrTable_t>(
                 GET_FUNCTION_PTR(loader, "zetGetCommandListProcAddrTable") );
-            result = getTable( ZE_API_VERSION_CURRENT, &zetDdiTable.CommandList );
+            result = getTable( ZE_API_VERSION_CURRENT, &initialzetDdiTable.CommandList );
         }
 
         if( ZE_RESULT_SUCCESS == result )
         {
             auto getTable = reinterpret_cast<zet_pfnGetKernelProcAddrTable_t>(
                 GET_FUNCTION_PTR(loader, "zetGetKernelProcAddrTable") );
-            result = getTable( ZE_API_VERSION_CURRENT, &zetDdiTable.Kernel );
+            result = getTable( ZE_API_VERSION_CURRENT, &initialzetDdiTable.Kernel );
         }
 
         if( ZE_RESULT_SUCCESS == result )
         {
             auto getTable = reinterpret_cast<zet_pfnGetModuleProcAddrTable_t>(
                 GET_FUNCTION_PTR(loader, "zetGetModuleProcAddrTable") );
-            result = getTable( ZE_API_VERSION_CURRENT, &zetDdiTable.Module );
+            result = getTable( ZE_API_VERSION_CURRENT, &initialzetDdiTable.Module );
         }
 
         if( ZE_RESULT_SUCCESS == result )
         {
             auto getTable = reinterpret_cast<zet_pfnGetDebugProcAddrTable_t>(
                 GET_FUNCTION_PTR(loader, "zetGetDebugProcAddrTable") );
-            result = getTable( ZE_API_VERSION_CURRENT, &zetDdiTable.Debug );
+            result = getTable( ZE_API_VERSION_CURRENT, &initialzetDdiTable.Debug );
         }
 
         if( ZE_RESULT_SUCCESS == result )
         {
             auto getTable = reinterpret_cast<zet_pfnGetMetricProcAddrTable_t>(
                 GET_FUNCTION_PTR(loader, "zetGetMetricProcAddrTable") );
-            result = getTable( ZE_API_VERSION_CURRENT, &zetDdiTable.Metric );
+            result = getTable( ZE_API_VERSION_CURRENT, &initialzetDdiTable.Metric );
+        }
+
+        if( ZE_RESULT_SUCCESS == result )
+        {
+            auto getTable = reinterpret_cast<zet_pfnGetMetricExpProcAddrTable_t>(
+                GET_FUNCTION_PTR(loader, "zetGetMetricExpProcAddrTable") );
+            result = getTable( ZE_API_VERSION_CURRENT, &initialzetDdiTable.MetricExp );
         }
 
         if( ZE_RESULT_SUCCESS == result )
         {
             auto getTable = reinterpret_cast<zet_pfnGetMetricGroupProcAddrTable_t>(
                 GET_FUNCTION_PTR(loader, "zetGetMetricGroupProcAddrTable") );
-            result = getTable( ZE_API_VERSION_CURRENT, &zetDdiTable.MetricGroup );
+            result = getTable( ZE_API_VERSION_CURRENT, &initialzetDdiTable.MetricGroup );
         }
 
         if( ZE_RESULT_SUCCESS == result )
         {
             auto getTable = reinterpret_cast<zet_pfnGetMetricGroupExpProcAddrTable_t>(
                 GET_FUNCTION_PTR(loader, "zetGetMetricGroupExpProcAddrTable") );
-            result = getTable( ZE_API_VERSION_CURRENT, &zetDdiTable.MetricGroupExp );
+            result = getTable( ZE_API_VERSION_CURRENT, &initialzetDdiTable.MetricGroupExp );
         }
 
         if( ZE_RESULT_SUCCESS == result )
         {
             auto getTable = reinterpret_cast<zet_pfnGetMetricQueryProcAddrTable_t>(
                 GET_FUNCTION_PTR(loader, "zetGetMetricQueryProcAddrTable") );
-            result = getTable( ZE_API_VERSION_CURRENT, &zetDdiTable.MetricQuery );
+            result = getTable( ZE_API_VERSION_CURRENT, &initialzetDdiTable.MetricQuery );
         }
 
         if( ZE_RESULT_SUCCESS == result )
         {
             auto getTable = reinterpret_cast<zet_pfnGetMetricQueryPoolProcAddrTable_t>(
                 GET_FUNCTION_PTR(loader, "zetGetMetricQueryPoolProcAddrTable") );
-            result = getTable( ZE_API_VERSION_CURRENT, &zetDdiTable.MetricQueryPool );
+            result = getTable( ZE_API_VERSION_CURRENT, &initialzetDdiTable.MetricQueryPool );
         }
 
         if( ZE_RESULT_SUCCESS == result )
         {
             auto getTable = reinterpret_cast<zet_pfnGetMetricStreamerProcAddrTable_t>(
                 GET_FUNCTION_PTR(loader, "zetGetMetricStreamerProcAddrTable") );
-            result = getTable( ZE_API_VERSION_CURRENT, &zetDdiTable.MetricStreamer );
+            result = getTable( ZE_API_VERSION_CURRENT, &initialzetDdiTable.MetricStreamer );
         }
 
         if( ZE_RESULT_SUCCESS == result )
         {
             auto getTable = reinterpret_cast<zet_pfnGetTracerExpProcAddrTable_t>(
                 GET_FUNCTION_PTR(loader, "zetGetTracerExpProcAddrTable") );
-            result = getTable( ZE_API_VERSION_CURRENT, &zetDdiTable.TracerExp );
+            result = getTable( ZE_API_VERSION_CURRENT, &initialzetDdiTable.TracerExp );
         }
 
         return result;
@@ -121,67 +135,77 @@ namespace ze_lib
 
         if( ZE_RESULT_SUCCESS == result )
         {
-            result = zetGetDeviceProcAddrTable( ZE_API_VERSION_CURRENT, &zetDdiTable.Device );
+            result = zetGetMetricProgrammableExpProcAddrTable( ZE_API_VERSION_CURRENT, &initialzetDdiTable.MetricProgrammableExp );
         }
 
         if( ZE_RESULT_SUCCESS == result )
         {
-            result = zetGetContextProcAddrTable( ZE_API_VERSION_CURRENT, &zetDdiTable.Context );
+            result = zetGetDeviceProcAddrTable( ZE_API_VERSION_CURRENT, &initialzetDdiTable.Device );
         }
 
         if( ZE_RESULT_SUCCESS == result )
         {
-            result = zetGetCommandListProcAddrTable( ZE_API_VERSION_CURRENT, &zetDdiTable.CommandList );
+            result = zetGetContextProcAddrTable( ZE_API_VERSION_CURRENT, &initialzetDdiTable.Context );
         }
 
         if( ZE_RESULT_SUCCESS == result )
         {
-            result = zetGetKernelProcAddrTable( ZE_API_VERSION_CURRENT, &zetDdiTable.Kernel );
+            result = zetGetCommandListProcAddrTable( ZE_API_VERSION_CURRENT, &initialzetDdiTable.CommandList );
         }
 
         if( ZE_RESULT_SUCCESS == result )
         {
-            result = zetGetModuleProcAddrTable( ZE_API_VERSION_CURRENT, &zetDdiTable.Module );
+            result = zetGetKernelProcAddrTable( ZE_API_VERSION_CURRENT, &initialzetDdiTable.Kernel );
         }
 
         if( ZE_RESULT_SUCCESS == result )
         {
-            result = zetGetDebugProcAddrTable( ZE_API_VERSION_CURRENT, &zetDdiTable.Debug );
+            result = zetGetModuleProcAddrTable( ZE_API_VERSION_CURRENT, &initialzetDdiTable.Module );
         }
 
         if( ZE_RESULT_SUCCESS == result )
         {
-            result = zetGetMetricProcAddrTable( ZE_API_VERSION_CURRENT, &zetDdiTable.Metric );
+            result = zetGetDebugProcAddrTable( ZE_API_VERSION_CURRENT, &initialzetDdiTable.Debug );
         }
 
         if( ZE_RESULT_SUCCESS == result )
         {
-            result = zetGetMetricGroupProcAddrTable( ZE_API_VERSION_CURRENT, &zetDdiTable.MetricGroup );
+            result = zetGetMetricProcAddrTable( ZE_API_VERSION_CURRENT, &initialzetDdiTable.Metric );
         }
 
         if( ZE_RESULT_SUCCESS == result )
         {
-            result = zetGetMetricGroupExpProcAddrTable( ZE_API_VERSION_CURRENT, &zetDdiTable.MetricGroupExp );
+            result = zetGetMetricExpProcAddrTable( ZE_API_VERSION_CURRENT, &initialzetDdiTable.MetricExp );
         }
 
         if( ZE_RESULT_SUCCESS == result )
         {
-            result = zetGetMetricQueryProcAddrTable( ZE_API_VERSION_CURRENT, &zetDdiTable.MetricQuery );
+            result = zetGetMetricGroupProcAddrTable( ZE_API_VERSION_CURRENT, &initialzetDdiTable.MetricGroup );
         }
 
         if( ZE_RESULT_SUCCESS == result )
         {
-            result = zetGetMetricQueryPoolProcAddrTable( ZE_API_VERSION_CURRENT, &zetDdiTable.MetricQueryPool );
+            result = zetGetMetricGroupExpProcAddrTable( ZE_API_VERSION_CURRENT, &initialzetDdiTable.MetricGroupExp );
         }
 
         if( ZE_RESULT_SUCCESS == result )
         {
-            result = zetGetMetricStreamerProcAddrTable( ZE_API_VERSION_CURRENT, &zetDdiTable.MetricStreamer );
+            result = zetGetMetricQueryProcAddrTable( ZE_API_VERSION_CURRENT, &initialzetDdiTable.MetricQuery );
         }
 
         if( ZE_RESULT_SUCCESS == result )
         {
-            result = zetGetTracerExpProcAddrTable( ZE_API_VERSION_CURRENT, &zetDdiTable.TracerExp );
+            result = zetGetMetricQueryPoolProcAddrTable( ZE_API_VERSION_CURRENT, &initialzetDdiTable.MetricQueryPool );
+        }
+
+        if( ZE_RESULT_SUCCESS == result )
+        {
+            result = zetGetMetricStreamerProcAddrTable( ZE_API_VERSION_CURRENT, &initialzetDdiTable.MetricStreamer );
+        }
+
+        if( ZE_RESULT_SUCCESS == result )
+        {
+            result = zetGetTracerExpProcAddrTable( ZE_API_VERSION_CURRENT, &initialzetDdiTable.TracerExp );
         }
 
         return result;
